// Size of the SVG container
const width = 500;
const height = 300;
const margin = { top: 20, right: 20, bottom: 30, left: 40 };
const chartWidth = width - margin.left - margin.right;
const chartHeight = height - margin.top - margin.bottom;

// Create SVG element
const svg = d3.select("#chart")
  .attr("width", width)
  .attr("height", height);

// Create a group for the chart
const chart = svg.append("g")
  .attr("transform", `translate(${margin.left}, ${margin.top})`);

// Scale functions
const xScale = d3.scaleBand()
  .domain(dataset.map(d => d.category))
  .range([0, chartWidth])
  .padding(0.1);

const yScale = d3.scaleLinear()
  .domain([0, d3.max(dataset, d => d.value)])
  .range([chartHeight, 0]);

// Create and append the bars to the chart
chart.selectAll(".bar")
  .data(dataset)
  .enter()
  .append("rect")
  .attr("class", "bar")
  .attr("x", d => xScale(d.category))
  .attr("y", d => yScale(d.value))
  .attr("width", xScale.bandwidth())
  .attr("height", d => chartHeight - yScale(d.value))
  .attr("fill", "steelblue");

// Append x and y-axis to the chart
const xAxis = d3.axisBottom(xScale);
const yAxis = d3.axisLeft(yScale);

chart.append("g")
  .attr("class", "x-axis")
  .attr("transform", `translate(0, ${chartHeight})`)
  .call(xAxis);

chart.append("g")
  .attr("class", "y-axis")
  .call(yAxis);

// Add labels for the axes
svg.append("text")
  .attr("transform", `translate(${width / 2}, ${height - margin.bottom})`)
  .style("text-anchor", "middle")
  .text("Categories");

svg.append("text")
  .attr("transform", "rotate(-90)")
  .attr("y", margin.left / 2)
  .attr("x", 0 - (height / 2))
  .style("text-anchor", "middle")
  .text("Values");

